==> pan-0.9.6.tar.gz: pan-0.9.6/pan/globals.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GLOBALS_H_
#define __GLOBALS_H_

#include <pthread.h>
#include <gtk/gtkwidget.h>
#include "article.h"

#ifndef MAXHOSTNAMELEN
#define MAXHOSTNAMELEN 255
#endif

#ifndef PATH_MAX
#define PATH_MAX 255
#endif

typedef struct
{
	pthread_t       main_t;
	GtkWidget     * window;	        /* main window for Pan */
	GtkWidget     * group_clist;	/* ??? */
	GtkWidget     * article_ctree;	/* ??? */
	GtkWidget     * widget;		/* ??? */
	GtkWidget     * text;		/* ??? */
	GSList        * serverlist;
	int             viewmode;
	gboolean        mute;		/* if true, outgoing
					   posts/mail are sent to
					   stdout instead of actually
					   being sent.  This is a
					   debugging tool. */
}
PanApp;

extern PanApp Pan;


#endif /* __PAN_H__ */

==> pan-0.12.1.tar.gz: pan-0.12.1/pan/globals.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000, 2001  Pan Development Team (pan@rebelbase.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __GLOBALS_H_
#define __GLOBALS_H_

#include <gtk/gtkwidget.h>
#include <pan/base/article.h>

#ifndef MAXHOSTNAMELEN
#define MAXHOSTNAMELEN 255
#endif

#ifndef PATH_MAX
#define PATH_MAX 255
#endif

typedef struct
{
	GThread       * main_t;
	GtkWidget     * window;	        /* main window for Pan */
	GtkWidget     * workarea;	/* workarea */
	GtkWidget     * group_tree;	/* ??? */
	GtkWidget     * article_ctree;	/* ??? */
	GtkWidget     * widget;		/* ??? */
	GtkWidget     * text;		/* ??? */
	int             viewmode;
	gboolean        mute;		/* if true, outgoing
					   posts/mail are sent to
					   stdout instead of actually
					   being sent.  This is a
					   debugging tool. */
}
PanApp;

extern PanApp Pan;


#endif /* __PAN_H__ */
